import convert from 'color-convert';

class Color {
    constructor(format, value) {
        this.value = value;
        this.format = format;
    }
}

class ConsistentShading {
    constructor(base, shades) {
        this._base = convert[base.format]['lch'](base.value);
        this._shades = new Array();
        this._deltas = new Array();
        shades.forEach((shade, index) => {
            const converted = convert[shade.format]['lch'](shade.value);
            this._shades.push(converted);
            this._deltas.push(converted[0] - this._base[0]);
        });
    }
    generate(base, exportFormat) {
        let exportFormatInUse;
        if (typeof exportFormat === 'undefined')
            exportFormatInUse = base.format;
        else
            exportFormatInUse = exportFormat;
        let exportedColors = [];
        const lchBase = convert[base.format]['lch'](base.value);
        this._deltas.forEach((delta) => {
            let lchGenerated = lchBase;
            lchGenerated[0] += delta;
            lchGenerated[0] = Math.min(100, Math.max(0, lchGenerated[0]));
            const generatedColor = new Color(exportFormatInUse, convert['lch'][exportFormatInUse](lchGenerated));
            exportedColors.push(generatedColor);
        });
        return exportedColors;
    }
}

export { Color, ConsistentShading };
//# sourceMappingURL=index.js.map
